/* 	EntryImpl.java
 * 
 * 	Created on: Nov 11, 2002
 * 	Created by: Dennis Groenendijk
 * 
 * Copyright (c) 2002-2006, Brains2B.org
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that
 * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 /* @#History
 * [When]		[Who]				[What]
 * 15-sep-03	dennis@brains2b.nl	Name changed from ListEntry
 * 28-11-2006   dennis@brains2b.nl  Made class serializable
 *
 */
package org.brains2b.collection;

import java.io.Serializable;

/** A Map.Entry written to rely on Strings instead
 * of objects
 * <p> Used primarely for Reference tables, JCombobox and the like. For that
 * reason the toString() returns only the value.
 * <p><i>Note: This is not an implementation of MapEntry</i>
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.20.1 [28-11-2006]
 * @see java.util.Map.Entry
 */
public class EntryImpl implements Serializable {

	private String m_key;
	private String m_value;

	/**
	 * Default Constructor for EntryImpl
	 */
	public EntryImpl() {
		super();
	}

	/**
	 *  Constructor for EntryImpl, initializes the values
	 * @param key 	String
	 * @param value	String
	 */
	public EntryImpl(String key, String value) {
		super();
		m_key=key;
		m_value=value;
	}

	/**
	 * Returns the key.
	 * @return String
	 */
	public String getKey() {
		return m_key;
	}

	/**
	 * Returns the value.
	 * @return String
	 */
	public String getValue() {
		return m_value;
	}

	/**
	 * The toString is equivalent to getValue() to
	 * make it possible to use it in a Combobox.
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		return m_value;
	}
	
	/**
	 * Compares this EntryImpl to another object to see if they are equal
	 * <UL>The following rules apply: 
	 * <LI> If comparing a EntryImpl equals returns true if they have the same key
	 * <LI>If comparing a String equals returns true if the String equals the key
	 * <LI>In all other cases false is returned.
	 * @see java.lang.Object#equals(Object)
	 */
	public boolean equals(Object obj) {
		if (obj==null) return false;
		if (obj instanceof EntryImpl && ((EntryImpl) obj).getKey()!=null && ((EntryImpl) obj).getKey().equals(m_key)) {
			return true;
		} else if (obj instanceof String && obj.equals(m_key)) {
			return true;
		}
		return false;
			
	}

	/**
	 * sets the Key
	 * <p>Prefered method is using the Constructor to initialize the object, instead
	 * of setting or updating the key here.
	 * @param key String
	 */
	public void setKey(String key) {
        m_key=key;
    }
    


	/**
	 * sets the Value
	 * <p>Prefered method is using the Constructor to initialize the object, instead
	 * of setting or updating the value here.
	 * @param value String
	 */
	public void setValue(String value) {
        m_value=value;
    }
    


	/**
	 *  Method paramString is used for testing purposes.
	 *  <p>Do not use this in runtime code for implementation may change, without notice
	 * @return String, returns the key and value seperated by a colon.
	 */
	public String paramString() {
        return m_key + ": " + m_value;
    }

}
