/* 	ArgumentException.java
 * 
 * 	Created on: Oct 2, 2002
 * 	Created by: Dennis Groenendijk
 * 
 * Copyright (c) 2002,2003 Brains2B.org
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that
 * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 /* @#History
 * [When]		[Who]				[What]
 * 06-Oct-03	dennis@brains2b.nl	Minor changes to the javadoc
 *
 */
package org.brains2b.console;

/** Exception for handling undefined arguments in the Main console class and
 *  accompanying ArgumentMap
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.11 [06-10-2003]
 */
public class ArgumentException extends Exception {

	/** Constant for error message <i>Not recognized as an argument</i>*/
	public final static String NOT_RECOGNIZED="Not recognized as an argument";
	/** Constant for error message <i>A required argument is missing</i>*/
	public final static String MISSING_ARGUMENT="A required argument is missing";

	private String m_arg;
	/**
	 * Constructor for ArgumentException.
	 * @param message String, the message for this Exception
	 */
	public ArgumentException(String message) {
		super(message);
	}

	/**
	 * Constructor for ArgumentException.
	 * @param arg String,  the argument for which the Exception was thrown
	 * @param message String, The exception message 
	 */
	public ArgumentException(String arg, String message) {
		super(message);
		m_arg=arg;
	}
	
	/**
	 * Gets the Argument for which the Exception was thrown
	 * @return String, the long name of the argument.
	 */
	public String getArgument() {
		return m_arg;
	}
	
}
