/* 	TaskEvent.java
 *	Copyright (c) 2002, Brains2B.org
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that
 * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.brains2b.task;

import java.awt.AWTEvent;

/** TaskEvent is fired when a task notifies its Listeners
 *  that it has either made progress or is finished
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.10 [12-07-2002]
 */
public class TaskEvent extends AWTEvent {

	private int m_min;
	private int m_max;
	private int m_position;
	private boolean m_finished=false;
	
	
	/**
	 * Constructor for TaskEvent.
	 * @param source
	 * @param id
	 */
	public TaskEvent(Object source, int id) {
		super(source, id);
	}

    /**
     * Constructor for TaskEvent.
     * @param source
     * @param id
     */
    public TaskEvent(Object source, int id, int min, int value,int max) {
        super(source, id);
        m_min=min;
        m_position=value;
        m_max=max;
    }

	/**
	 * Gets the minimum position .
	 * @return Returns a int
	 */
	public int getMin() {
		return m_min;
	}

	/**
	 * Sets the mininum position.
	 * @param min The min to set
	 */
	void setMin(int min) {
		m_min = min;
	}

	/**
	 * Gets the maximum position.
	 * @return Returns a int
	 */
	public int getMax() {
		return m_max;
	}

	/**
	 * Sets the maximum position.
	 * @param max The max to set
	 */
	void setMax(int max) {
		m_max = max;
	}

	/**
	 * Gets the position.
	 * @return Returns a int
	 */
	public int getPosition() {
		return m_position;
	}

	/**
	 * Sets the position.
	 * @param position The position to set
	 */
	void setPosition(int position) {
		m_position = position;
	}

	/**
	 * True if Task has finished
	 * @return Returns a boolean
	 */
	public boolean isFinished() {
		return m_finished;
	}

	/**
	 * set to true if task has finished
	 * @param finished The finished to set
	 */
	public void setFinished(boolean finished) {
		m_finished = finished;
	}

}
