/* 	GuiHelper.java
 *	Copyright (c) 2001, Dennis Groenendijk
 * 			  (c) 2002-2007, Brains2B.org
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that
 * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/*
 * @#History 
 * [When]       [Who]               [What] 
 * 28-11-2006   dennis@brains2b.nl  encode,decode Dimensions
 * 30-06-2007   dennis@brains2b.nl  removed useless setMiddle(Dimension, Rectangle) method
 * 03-10-2007   dennis@brains2b.nl  protect setMiddle against negative values
 */
package org.brains2b.util;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;

import javax.swing.JLabel;
import javax.swing.SwingUtilities;

/**
 * Static help function for GUI related items
 * 
 * @author  Dennis Groenendijk
 * @version 1.10.1 [03-10-2007]
 * 
 */
public class GuiHelper {
    
    /**
     * Don't initialize this class
     */
    private GuiHelper() {
    }
	/**
	 * Calculates Middle for a target from a source
     * @return java.awt.Rectangle
	 * @param target java.awt.Rectangle
	 * @param source java.awt.Rectangle
     * @throws IllegalArgumentException if either source or target is null
	 */
	public static java.awt.Rectangle setMiddle(
		java.awt.Rectangle target,
		java.awt.Rectangle source) {
        if (target==null || source==null) 
            throw new IllegalArgumentException("Cannot calculate middle if source or target is null");
		target.x = Math.max(source.x, (int) source.getCenterX() - (target.width / 2));
		target.y = Math.max(source.y, (int) source.getCenterY() - (target.height / 2));
		return target;
	}

    public final static Dimension decodeDimension(String dim) {
        if (StringHelper.isEmpty(dim)) return null;
        Dimension d=new Dimension();
        try {
            int idx=dim.indexOf(',');
            if (idx==-1) {
                d.width=Integer.parseInt(dim);
                d.height=Integer.parseInt(dim);
            } else {
                d.width=Integer.parseInt(dim.substring(0,idx));
                d.height=Integer.parseInt(dim.substring(idx+1));
            }
        } catch (NumberFormatException nfex) {
            d=null;
        }
        
        return d;
    }
    
    public final static String encodeDimension(Dimension d) {
        if (d==null) return null;
        StringBuffer sb = new StringBuffer();
        sb.append(d.width).append(',').append(d.height);
        return sb.toString();
    }
	/**
	 * Calculates Width in pixels on the basis of String
	 * The default font from a Swing component is used get the necessary metrics.
	 * @param str String
	 */
	public static int getWidth(String str) {
        if (str==null) return 0;
		JLabel jl = new JLabel();
		str = str + "M";
		int w =
			SwingUtilities.computeStringWidth(
				jl.getFontMetrics(jl.getFont()),
				str);
		return (w);

	}

	/**
	 * Calculates the width in pixels of a given string and return the
	 * longer of the string length or the given width.
	 * @param str String
	 */
	public static int getWidth(String str, int width) {
		int w = getWidth(str);
		return (w > width ? w : width);

	}

	/**
	 * check if a value supplied as a String contains
	 * the information to be used as a Color
	 * @param value String, the value to be used as Color
	 * @return true if the value can be used as a color, false
	 * otherwise
	 * @since TwelBox 0.33
	 */
	public static boolean isColor(String value) {
		try {
			Color c = Color.decode(value);
			if (c != null) return true;
		} catch (Exception e) {
		}
		return false;
	}

	/**
	 * check if a value supplied as a String contains
	 * the information to be used as a Font
	 * @param value String, the value to be used as Font
	 * @return true if the value can be used as a Font, false
	 * otherwise
	 * @since TwelBox 0.33
	 */
	public static boolean isFont(String value) {
        if (value==null) return false;
		try {
			Font f = Font.decode(value);
			if (f != null) return true;
		} catch (Exception e) {
		}
		return false;

	}

}
