/* 	ArgumentMapTest.java
 * 
 * 	Created on: Oct 02, 2002
 * 	Created by: Dennis Groenendijk
 * 
 * Copyright (c) 2002, Brains2B.org
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that
 * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package test.org.brains2b.console;

import java.util.Map;

import junit.framework.TestCase;

import org.brains2b.console.ArgumentException;
import org.brains2b.console.ArgumentMap;

/** Unit test for org.brains2b.console.ArgumentMap
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.1 [02-10-2002]
 * @see org.brains2b.console.ArgumentMap
 */
public class ArgumentMapTest extends TestCase {

	/**
	 * Constructor for ArgumentMapTest.
	 * @param arg0
	 */
	public ArgumentMapTest(String arg0) {
		super(arg0);
	}

	public static void main(String[] args) {
		junit.swingui.TestRunner.run(ArgumentMapTest.class);
	}

	public void testOne() {
		ArgumentMap map=new ArgumentMap();
		map.addArgument("infile",false);
		
		try {
			Map list=map.getList(new String[] {"/tmp/file.txt"});
			assertEquals(list.get("infile"),"/tmp/file.txt");
		} catch (ArgumentException aex) {
			assertTrue(aex.getMessage(),false);
		}
		
		
	}
	
	public void testTwo() {
		ArgumentMap map=new ArgumentMap();
		map.addArgument("outfile",true);
        map.addArgument("infile",true);
		try {
			Map list=map.getList(new String[] {"/tmp/out.txt","/tmp/in.txt"});
			assertEquals(list.get("infile"),"/tmp/in.txt");
			assertEquals(list.get("outfile"),"/tmp/out.txt");
		} catch (ArgumentException aex) {
			assertTrue(aex.getMessage(),false);
		}
		
	}
	
	public void testThree() {
		ArgumentMap map=new ArgumentMap();
		map.addArgument("action",true);
		map.addOptionTo("action","screen",'s');
		map.addOptionTo("action","batch",'b');
		map.addOptionTo("action","element",'e');
		
		try {
			Map list=map.getList(new String[] {"-s"});
			assertEquals(list.get("action"),"screen");
		} catch (ArgumentException aex) {
			assertTrue(aex.getMessage(),false);
		}
	}
	
	public void testFour() {
		ArgumentMap map=new ArgumentMap();
		map.addArgument("action",true);
		map.addOptionTo("action","screen",'s');
		map.addOptionTo("action","batch",'b');
		map.addOptionTo("action","element",'e');
		
		try {
			Map list=map.getList(new String[] {"--screen"});
			assertEquals(list.get("action"),"screen");
		} catch (ArgumentException aex) {
			assertTrue(aex.getMessage(),false);
		}
	}
	
	public void testFive() {
		ArgumentMap map=new ArgumentMap();
		map.addArgument("action",true);
		map.addOptionTo("action","screen",'s');
		map.addOptionTo("action","batch",'b');
		map.addOptionTo("action","element",'e');
		
		try {
			Map list=map.getList(new String[] {"-s","-b"});
			assertEquals(list.get("action"),"screen");
		} catch (ArgumentException aex) {
			assertTrue(aex.getMessage(),false);
		}	
	}

	public void testSix() {
		ArgumentMap map=new ArgumentMap();
		map.addOption("out",'o',false);
		map.addArgumentTo("out","file",true);
		
		try {
			Map list=map.getList(new String[] {"-o","/tmp/out.txt"});
			assertEquals(list.get("out"),"/tmp/out.txt");
		} catch (ArgumentException aex) {
			assertTrue(aex.getMessage(),false);
		}	
	}	
	
	public void testSeven() {
		ArgumentMap map=new ArgumentMap();
		map.addOption("out",'o',false);
		map.addArgumentTo("out","file",true);
		
		try {
			map.getList(new String[] {"-o"});
			assertTrue(false);
		} catch (ArgumentException aex) {
			assertTrue(aex.getMessage(),true);
		}	
	}	
	
	public void testEight() {
		ArgumentMap map=new ArgumentMap();
		map.addArgument("action","standard.out");
		map.addOptionTo("action","file",'f');
		map.addOptionTo("action","url",'u');
		map.addOptionTo("action","print",'p');
		
		try {
			Map list=map.getList(new String[] {});
			assertEquals(list.get("action"),"standard.out");
		} catch (ArgumentException aex) {
			assertTrue(aex.getMessage(),false);
		}	
	}
    
    public void testCompressedForm() {
        ArgumentMap map = new ArgumentMap();
        map.addOption("list",'l',false);
        map.addOption("extract",'x',false);
        map.addOption("file",'f',true);
        map.addArgumentTo("file","name",true);
        try {
            Map list=map.getList(new String[] {"-lxf","/tmp/out.txt"});
            assertEquals(list.get("file"),"/tmp/out.txt");
            assertEquals("true",list.get("list"));
            assertEquals("true",list.get("extract"));
        } catch (ArgumentException aex) {
            assertTrue(aex.getMessage(),false);
        }
    }
        
    public void testCompressedForm2() {
        ArgumentMap map = new ArgumentMap();
        map.addOption("list",'l',false);
        map.addOption("extract",'x',false);
        map.addOption("file",'f',true);
        map.addArgumentTo("file","name",true);
        try {
            Map list=map.getList(new String[] {"-lf","/tmp/out.txt"});
            assertEquals(list.get("file"),"/tmp/out.txt");
            assertEquals("true",list.get("list"));
            assertNull(list.get("extract"));
        } catch (ArgumentException aex) {
            assertTrue(aex.getMessage(),false);
        }   
    }
    
    public void testCompressedWithOption() {
        ArgumentMap map=new ArgumentMap();
        map.addOption("list",'l',false);
        map.addOption("extract",'x',false);
        map.addArgument("action",true);
        map.addOptionTo("action","screen",'s');
        map.addOptionTo("action","batch",'b');
        map.addOptionTo("action","element",'e');
        
        try {
            Map list=map.getList(new String[] {"-lxs"});
            assertEquals(list.get("action"),"screen");
            assertEquals(list.get("list"),"true");
            assertEquals(list.get("extract"),"true");
        } catch (ArgumentException aex) {
            assertTrue(aex.getMessage(),false);
        }   
    }
     
}
